@@ -23,10 +23,12 @@
 #include <sys/socket.h>
 
 static constexpr QLatin1StringView SOLID_POWERMANAGEMENT_SERVICE("org.kde.Solid.PowerManagement");
+static constexpr QLatin1StringView UPOWER_POWERPROFILE_SERVICE("net.hadess.PowerProfiles");
 
 PowerProfilesControl::PowerProfilesControl(QObject *parent)
     : QObject(parent)
     , m_solidWatcher(new QDBusServiceWatcher)
+    , m_powerProfileWatcher(new QDBusServiceWatcher)
 {
     qDBusRegisterMetaType<QList<QVariantMap>>();
     qDBusRegisterMetaType<QVariantMap>();
@@ -38,8 +40,18 @@ PowerProfilesControl::PowerProfilesControl(QObject *parent)
 
     connect(m_solidWatcher.get(), &QDBusServiceWatcher::serviceRegistered, this, &PowerProfilesControl::onServiceRegistered);
     connect(m_solidWatcher.get(), &QDBusServiceWatcher::serviceUnregistered, this, &PowerProfilesControl::onServiceUnregistered);
+
+    // Watch for PowerDevil's power management service
+    m_powerProfileWatcher->setConnection(QDBusConnection::systemBus());
+    m_powerProfileWatcher->setWatchMode(QDBusServiceWatcher::WatchForRegistration | QDBusServiceWatcher::WatchForUnregistration);
+    m_powerProfileWatcher->addWatchedService(UPOWER_POWERPROFILE_SERVICE);
+
+    connect(m_powerProfileWatcher.get(), &QDBusServiceWatcher::serviceRegistered, this, &PowerProfilesControl::onServiceRegistered);
+    connect(m_powerProfileWatcher.get(), &QDBusServiceWatcher::serviceUnregistered, this, &PowerProfilesControl::onServiceUnregistered);
+
     // If it's up and running already, let's cache it
-    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(SOLID_POWERMANAGEMENT_SERVICE)) {
+    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(SOLID_POWERMANAGEMENT_SERVICE)
+        && QDBusConnection::systemBus().interface()->isServiceRegistered(UPOWER_POWERPROFILE_SERVICE)) {
         onServiceRegistered(SOLID_POWERMANAGEMENT_SERVICE);
     }
 }
@@ -50,9 +62,10 @@ PowerProfilesControl::~PowerProfilesControl()
 
 void PowerProfilesControl::onServiceRegistered(const QString &serviceName)
 {
-    if (serviceName == SOLID_POWERMANAGEMENT_SERVICE) {
-        if (QDBusConnection::systemBus().interface()->isServiceRegistered(QStringLiteral("net.hadess.PowerProfiles"))) {
-            QDBusMessage profileChoices = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
+    if (serviceName == SOLID_POWERMANAGEMENT_SERVICE || serviceName == UPOWER_POWERPROFILE_SERVICE) {
+        if (QDBusConnection::systemBus().interface()->isServiceRegistered(UPOWER_POWERPROFILE_SERVICE)
+            && QDBusConnection::sessionBus().interface()->isServiceRegistered(SOLID_POWERMANAGEMENT_SERVICE)) {
+            QDBusMessage profileChoices = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
                                                                          QStringLiteral("/org/kde/Solid/PowerManagement/Actions/PowerProfile"),
                                                                          QStringLiteral("org.kde.Solid.PowerManagement.Actions.PowerProfile"),
                                                                          QStringLiteral("profileChoices"));
@@ -69,7 +82,7 @@ void PowerProfilesControl::onServiceRegistered(const QString &serviceName)
                 watcher->deleteLater();
             });
 
-            QDBusMessage configuredProfile = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
+            QDBusMessage configuredProfile = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
                                                                             QStringLiteral("/org/kde/Solid/PowerManagement/Actions/PowerProfile"),
                                                                             QStringLiteral("org.kde.Solid.PowerManagement.Actions.PowerProfile"),
                                                                             QStringLiteral("configuredProfile"));
@@ -85,7 +98,7 @@ void PowerProfilesControl::onServiceRegistered(const QString &serviceName)
                 watcher->deleteLater();
             });
 
-            QDBusMessage currentProfile = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
+            QDBusMessage currentProfile = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
                                                                          QStringLiteral("/org/kde/Solid/PowerManagement/Actions/PowerProfile"),
                                                                          QStringLiteral("org.kde.Solid.PowerManagement.Actions.PowerProfile"),
                                                                          QStringLiteral("currentProfile"));
@@ -101,7 +114,7 @@ void PowerProfilesControl::onServiceRegistered(const QString &serviceName)
                 watcher->deleteLater();
             });
 
-            QDBusMessage inhibitionReason = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
+            QDBusMessage inhibitionReason = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
                                                                            QStringLiteral("/org/kde/Solid/PowerManagement/Actions/PowerProfile"),
                                                                            QStringLiteral("org.kde.Solid.PowerManagement.Actions.PowerProfile"),
                                                                            QStringLiteral("performanceInhibitedReason"));
@@ -117,7 +130,7 @@ void PowerProfilesControl::onServiceRegistered(const QString &serviceName)
                 watcher->deleteLater();
             });
 
-            QDBusMessage degradedReason = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
+            QDBusMessage degradedReason = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
                                                                          QStringLiteral("/org/kde/Solid/PowerManagement/Actions/PowerProfile"),
                                                                          QStringLiteral("org.kde.Solid.PowerManagement.Actions.PowerProfile"),
                                                                          QStringLiteral("performanceDegradedReason"));
@@ -133,7 +146,7 @@ void PowerProfilesControl::onServiceRegistered(const QString &serviceName)
                 watcher->deleteLater();
             });
 
-            QDBusMessage profileHolds = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
+            QDBusMessage profileHolds = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
                                                                        QStringLiteral("/org/kde/Solid/PowerManagement/Actions/PowerProfile"),
                                                                        QStringLiteral("org.kde.Solid.PowerManagement.Actions.PowerProfile"),
                                                                        QStringLiteral("profileHolds"));
@@ -202,17 +215,20 @@ void PowerProfilesControl::onServiceRegistered(const QString &serviceName)
                                                        SLOT(updatePowerProfileHolds(QList<QVariantMap>)))) {
                 qCDebug(APPLETS::BATTERYMONITOR) << "error connecting to profile hold changes via dbus";
             }
-            m_isTlpInstalled = false;
+
             m_isPowerProfileDaemonInstalled = true;
+            Q_EMIT isPowerProfileDaemonInstalledChanged(true);
+
+            setTlpInstalled(false);
         } else {
-            m_isTlpInstalled = !QStandardPaths::findExecutable(QStringLiteral("tlp")).isEmpty();
+            setTlpInstalled(!QStandardPaths::findExecutable(QStringLiteral("tlp")).isEmpty());
         }
     }
 }
 
 void PowerProfilesControl::onServiceUnregistered(const QString &serviceName)
 {
-    if (serviceName == SOLID_POWERMANAGEMENT_SERVICE) {
+    if ((serviceName == SOLID_POWERMANAGEMENT_SERVICE || serviceName == UPOWER_POWERPROFILE_SERVICE) && m_isPowerProfileDaemonInstalled) {
         m_isPowerProfileDaemonInstalled = false;
         // leave m_isTlpInstalled as is, it's not going to change just because PowerDevil disappeared
 
@@ -265,12 +281,16 @@ void PowerProfilesControl::onServiceUnregistered(const QString &serviceName)
         updatePowerProfileCurrentProfile(QString());
         updatePowerProfileConfiguredProfile(QString());
         m_profileError = QString();
+        Q_EMIT isPowerProfileDaemonInstalledChanged(false);
     }
 }
 
-bool PowerProfilesControl::isTlpInstalled() const
+void PowerProfilesControl::setTlpInstalled(bool installed)
 {
-    return m_isTlpInstalled;
+    if (installed != m_isTlpInstalled) {
+        m_isTlpInstalled = installed;
+        Q_EMIT isTlpInstallChanged(m_isTlpInstalled);
+    }
 }
 
 bool PowerProfilesControl::isSilent()
@@ -323,9 +343,14 @@ QBindable<QList<QVariantMap>> PowerProfilesControl::bindableProfileHolds()
     return &m_profileHolds;
 }
 
+QBindable<bool> PowerProfilesControl::bindableIsTlpInstalled()
+{
+    return &m_isTlpInstalled;
+}
+
 void PowerProfilesControl::setProfile(const QString &profile)
 {
-    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
+    QDBusMessage msg = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
                                                       QStringLiteral("/org/kde/Solid/PowerManagement/Actions/PowerProfile"),
                                                       QStringLiteral("org.kde.Solid.PowerManagement.Actions.PowerProfile"),
                                                       QStringLiteral("setProfile"));
