@@ -42,10 +42,13 @@ class BacklightBrightness : public DisplayBrightness
     Q_OBJECT
 
 public:
+    QString id() const override;
+    QString label() const override;
     int knownSafeMinBrightness() const override;
     int maxBrightness() const override;
     int brightness() const override;
     void setBrightness(int brightness) override;
+    bool isInternal() const override;
 
 private Q_SLOTS:
     void onDeviceChanged(const UdevQt::Device &device);
